#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-wl-pprint
version:              1.0.2
visibility:           public
id:                   ansi-wl-pprint-1.0.2-LXw84cylI3B9k4kvgmKzd1
key:                  ansi-wl-pprint-1.0.2-LXw84cylI3B9k4kvgmKzd1
license:              BSD-3-Clause
maintainer:           Edward Kmett <ekmett@gmail.com>
author:               Daan Leijen, Max Bolingbroke
homepage:             http://github.com/ekmett/ansi-wl-pprint
synopsis:
    The Wadler/Leijen Pretty Printer for colored ANSI terminal output

description:
    This is a pretty printing library based on Wadler'\''s paper ["A Prettier Printer"](https://homepages.inf.ed.ac.uk/wadler/papers/prettier/prettier.pdf).
    It has been enhanced with support for ANSI terminal colored output using the [ansi-terminal](https://hackage.haskell.org/package/ansi-terminal) package.

category:             User Interfaces, Text
abi:                  93aaa95d461fe46c9e1324b7f418343b
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ansi-wl-pprint-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-wl-pprint
hs-libraries:         HSansi-wl-pprint-1.0.2-LXw84cylI3B9k4kvgmKzd1
depends:
    base-4.18.2.1
    prettyprinter-compat-ansi-wl-pprint-1.0.2-KLyOVk3bmYC2exQ4RuHjOf

haddock-interfaces:
    /usr/share/doc/haskell-ansi-wl-pprint/html/ansi-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

